==> fet_5.9.1.orig.tar.gz: fet-5.9.1/src/interface/addconstraintstudentssetnotavailabletimesform.h <==
/***************************************************************************
                          addconstraintstudentssetnotavailabletimesform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTSTUDENTSSETNOTAVAILABLETIMESFORM_H
#define ADDCONSTRAINTSTUDENTSSETNOTAVAILABLETIMESFORM_H

#include "addconstraintstudentssetnotavailabletimesform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>

class AddConstraintStudentsSetNotAvailableTimesForm : public AddConstraintStudentsSetNotAvailableTimesForm_template  {
	Q_OBJECT
public:
	AddConstraintStudentsSetNotAvailableTimesForm();
	~AddConstraintStudentsSetNotAvailableTimesForm();

	void updateStudentsSetComboBox();

	void addCurrentConstraint();
public slots:	
	void tableClicked(int, int, int, const QPoint&);
	void help();

	void setAllAvailable();
	void setAllNotAvailable();
};

#endif

==> fet_5.11.0.orig.tar.gz: fet-5.11.0/src/interface/addconstraintstudentssetnotavailabletimesform.h <==
/***************************************************************************
                          addconstraintstudentssetnotavailabletimesform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTSTUDENTSSETNOTAVAILABLETIMESFORM_H
#define ADDCONSTRAINTSTUDENTSSETNOTAVAILABLETIMESFORM_H

#include "ui_addconstraintstudentssetnotavailabletimesform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>

class AddConstraintStudentsSetNotAvailableTimesForm : public QDialog, Ui::AddConstraintStudentsSetNotAvailableTimesForm_template  {
	Q_OBJECT
public:
	AddConstraintStudentsSetNotAvailableTimesForm();
	~AddConstraintStudentsSetNotAvailableTimesForm();

	void updateStudentsSetComboBox();

	void colorItem(QTableWidgetItem* item);

public slots:	
	void addCurrentConstraint();

	void itemClicked(QTableWidgetItem* item);
	void horizontalHeaderClicked(int col);
	void verticalHeaderClicked(int row);

	void help();

	void setAllAvailable();
	void setAllNotAvailable();
};

#endif
